==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/appplatform/kotlin/inputs/BuilderPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appplatform.kotlin.inputs

import com.pulumi.azurenative.appplatform.inputs.BuilderPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * KPack Builder properties payload
 * @property buildpackGroups Builder buildpack groups.
 * @property stack Builder cluster stack property.
 */
public data class BuilderPropertiesArgs(
    public val buildpackGroups: Output<List<BuildpacksGroupPropertiesArgs>>? = null,
    public val stack: Output<StackPropertiesArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.appplatform.inputs.BuilderPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.appplatform.inputs.BuilderPropertiesArgs =
        com.pulumi.azurenative.appplatform.inputs.BuilderPropertiesArgs.builder()
            .buildpackGroups(
                buildpackGroups?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .stack(stack?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [BuilderPropertiesArgs].
 */
@PulumiTagMarker
public class BuilderPropertiesArgsBuilder internal constructor() {
    private var buildpackGroups: Output<List<BuildpacksGroupPropertiesArgs>>? = null

    private var stack: Output<StackPropertiesArgs>? = null

    /**
     * @param value Builder buildpack groups.
     */
    @JvmName("qwsmfadkokwgecch")
    public suspend fun buildpackGroups(`value`: Output<List<BuildpacksGroupPropertiesArgs>>) {
        this.buildpackGroups = value
    }

    @JvmName("riwrlypibsnsvftp")
    public suspend fun buildpackGroups(vararg values: Output<BuildpacksGroupPropertiesArgs>) {
        this.buildpackGroups = Output.all(values.asList())
    }

    /**
     * @param values Builder buildpack groups.
     */
    @JvmName("pmkxckymrypbytti")
    public suspend fun buildpackGroups(values: List<Output<BuildpacksGroupPropertiesArgs>>) {
        this.buildpackGroups = Output.all(values)
    }

    /**
     * @param value Builder cluster stack property.
     */
    @JvmName("wpaiokbuperkipii")
    public suspend fun stack(`value`: Output<StackPropertiesArgs>) {
        this.stack = value
    }

    /**
     * @param value Builder buildpack groups.
     */
    @JvmName("ypipmvcbyloiyqau")
    public suspend fun buildpackGroups(`value`: List<BuildpacksGroupPropertiesArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.buildpackGroups = mapped
    }

    /**
     * @param argument Builder buildpack groups.
     */
    @JvmName("jmsichrsawydtlqn")
    public suspend
    fun buildpackGroups(argument: List<suspend BuildpacksGroupPropertiesArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            BuildpacksGroupPropertiesArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.buildpackGroups = mapped
    }

    /**
     * @param argument Builder buildpack groups.
     */
    @JvmName("mkuprtyduxriiurx")
    public suspend fun buildpackGroups(
        vararg
        argument: suspend BuildpacksGroupPropertiesArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            BuildpacksGroupPropertiesArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.buildpackGroups = mapped
    }

    /**
     * @param argument Builder buildpack groups.
     */
    @JvmName("jbsjvfdekpydtrkd")
    public suspend
    fun buildpackGroups(argument: suspend BuildpacksGroupPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            BuildpacksGroupPropertiesArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.buildpackGroups = mapped
    }

    /**
     * @param values Builder buildpack groups.
     */
    @JvmName("kdcyjvwguarseupl")
    public suspend fun buildpackGroups(vararg values: BuildpacksGroupPropertiesArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.buildpackGroups = mapped
    }

    /**
     * @param value Builder cluster stack property.
     */
    @JvmName("arfkotatbhbeqrui")
    public suspend fun stack(`value`: StackPropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.stack = mapped
    }

    /**
     * @param argument Builder cluster stack property.
     */
    @JvmName("ipiiitarngdlwabt")
    public suspend fun stack(argument: suspend StackPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = StackPropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.stack = mapped
    }

    internal fun build(): BuilderPropertiesArgs = BuilderPropertiesArgs(
        buildpackGroups = buildpackGroups,
        stack = stack,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/appplatform/kotlin/inputs/BuilderPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appplatform.kotlin.inputs

import com.pulumi.azurenative.appplatform.inputs.BuilderPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * KPack Builder properties payload
 * @property buildpackGroups Builder buildpack groups.
 * @property stack Builder cluster stack property.
 */
public data class BuilderPropertiesArgs(
    public val buildpackGroups: Output<List<BuildpacksGroupPropertiesArgs>>? = null,
    public val stack: Output<StackPropertiesArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.appplatform.inputs.BuilderPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.appplatform.inputs.BuilderPropertiesArgs =
        com.pulumi.azurenative.appplatform.inputs.BuilderPropertiesArgs.builder()
            .buildpackGroups(
                buildpackGroups?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .stack(stack?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [BuilderPropertiesArgs].
 */
@PulumiTagMarker
public class BuilderPropertiesArgsBuilder internal constructor() {
    private var buildpackGroups: Output<List<BuildpacksGroupPropertiesArgs>>? = null

    private var stack: Output<StackPropertiesArgs>? = null

    /**
     * @param value Builder buildpack groups.
     */
    @JvmName("uvqjqrmdlmkckpfm")
    public suspend fun buildpackGroups(`value`: Output<List<BuildpacksGroupPropertiesArgs>>) {
        this.buildpackGroups = value
    }

    @JvmName("csdyndfqaeugqcst")
    public suspend fun buildpackGroups(vararg values: Output<BuildpacksGroupPropertiesArgs>) {
        this.buildpackGroups = Output.all(values.asList())
    }

    /**
     * @param values Builder buildpack groups.
     */
    @JvmName("seemxlvmntdkpcjp")
    public suspend fun buildpackGroups(values: List<Output<BuildpacksGroupPropertiesArgs>>) {
        this.buildpackGroups = Output.all(values)
    }

    /**
     * @param value Builder cluster stack property.
     */
    @JvmName("qelamnccgwrkiwld")
    public suspend fun stack(`value`: Output<StackPropertiesArgs>) {
        this.stack = value
    }

    /**
     * @param value Builder buildpack groups.
     */
    @JvmName("nblhlhkgkicdxams")
    public suspend fun buildpackGroups(`value`: List<BuildpacksGroupPropertiesArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.buildpackGroups = mapped
    }

    /**
     * @param argument Builder buildpack groups.
     */
    @JvmName("mqghowijhhbapcwj")
    public suspend
    fun buildpackGroups(argument: List<suspend BuildpacksGroupPropertiesArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            BuildpacksGroupPropertiesArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.buildpackGroups = mapped
    }

    /**
     * @param argument Builder buildpack groups.
     */
    @JvmName("vwmjcdqaxyhykemk")
    public suspend fun buildpackGroups(
        vararg
        argument: suspend BuildpacksGroupPropertiesArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            BuildpacksGroupPropertiesArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.buildpackGroups = mapped
    }

    /**
     * @param argument Builder buildpack groups.
     */
    @JvmName("cvedcbuincqelhfh")
    public suspend
    fun buildpackGroups(argument: suspend BuildpacksGroupPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            BuildpacksGroupPropertiesArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.buildpackGroups = mapped
    }

    /**
     * @param values Builder buildpack groups.
     */
    @JvmName("yoljvybrbvabysdl")
    public suspend fun buildpackGroups(vararg values: BuildpacksGroupPropertiesArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.buildpackGroups = mapped
    }

    /**
     * @param value Builder cluster stack property.
     */
    @JvmName("hmjthxnctkurqybw")
    public suspend fun stack(`value`: StackPropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.stack = mapped
    }

    /**
     * @param argument Builder cluster stack property.
     */
    @JvmName("jvmlqdpwasnvogyk")
    public suspend fun stack(argument: suspend StackPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = StackPropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.stack = mapped
    }

    internal fun build(): BuilderPropertiesArgs = BuilderPropertiesArgs(
        buildpackGroups = buildpackGroups,
        stack = stack,
    )
}
